@@ -3,6 +3,7 @@
 :author: Shay Hill
 :created: 12/22/2019.
 """
+from svg_ultralight.bounding_boxes.supports_bounds import SupportsBounds
 from svg_ultralight.bounding_boxes.type_bound_element import BoundElement
 from svg_ultralight.bounding_boxes.type_bounding_box import BoundingBox
 from svg_ultralight.bounding_boxes.type_padded_text import PaddedText
@@ -27,6 +28,7 @@ __all__ = [
     "BoundElement",
     "BoundingBox",
     "PaddedText",
+    "SupportsBounds",
     "new_element",
     "new_sub_element",
     "update_element",
